---
title: "Overview"
---

Welcome to DASCore's cookbook! This is a collection of examples (recipes) for performing common processing tasks.
Please look around and consider [contributing](../contributing/contributing.qmd) some examples of your
own.

# Contributing

[Contributing to documentation](contributing_to_documentation.qmd)

[Contributing step by step](how_to_contribute.qmd)
